@@ -139,10 +139,16 @@ class DiscovererThread(Thread):
             for tag, value in sound_file.tags.items():
                 logger.debug('    {}: {}'.format(tag, value))
 
+            duration = info.get_duration() / Gst.SECOND
+            if duration == 0:
+                # might be an image
+                return
+
             # since threads share memory, this doesn't have to be sent
             # over a bus or queue, but rather can be written into the
             # sound_file
-            sound_file.duration = info.get_duration() / Gst.SECOND
+            sound_file.duration = duration
+
             sound_file.readable = True
         except Exception as error:
             if not isinstance(error, GLib.Error):
@@ -179,6 +185,8 @@ class Discoverer(Task):
         self.bus = None
         self.thread = None
 
+        super().__init__()
+
     def get_progress(self):
         """Fraction of how much of the task is completed."""
         return self.discovered / len(self.sound_files), 1
@@ -186,7 +194,7 @@ class Discoverer(Task):
     def cancel(self):
         """Cancel execution of the task."""
         # fast task, use case doesn't exist
-        self.callback()
+        self.done()
 
     def pause(self):
         """Pause execution of the task."""
@@ -210,6 +218,6 @@ class Discoverer(Task):
         """Write down that it is finished and call the callback."""
         if message.type == Gst.MessageType.EOS:
             self.running = False
-            self.callback()
+            self.done()
         else:
             self.discovered += 1
