@@ -120,6 +120,7 @@ class BatchUtils(unittest.TestCase):
             'file://' + urllib.parse.quote(os.path.realpath('test data/audio/strângë chàrs фズ.wav')),
             'file://' + os.path.realpath('test%20data/empty/a'),
             'file://' + os.path.realpath('test%20data/empty/b/c'),
+            'file://' + os.path.realpath('test%20data/image.jpg'),
             'file://' + os.path.realpath('test%20data/a.iso'),
             'file://' + os.path.realpath('test%20data/no%20tags/no-tags.mp3'),
             'file://' + os.path.realpath('test%20data/no%20tags/no-tags.ogg'),
@@ -143,6 +144,7 @@ class BatchUtils(unittest.TestCase):
             'test data/empty/',
             'test data/empty/b/',
             'test data/',
+            'test data/',
             'test data/no tags/',
             'test data/no tags/',
             'test data/no tags/'
@@ -161,6 +163,7 @@ class BatchUtils(unittest.TestCase):
             'file://' + urllib.parse.quote(os.path.realpath('tests/test data/audio/strângë chàrs фズ.wav')),
             'file://' + os.path.realpath('tests/test%20data/empty/a'),
             'file://' + os.path.realpath('tests/test%20data/empty/b/c'),
+            'file://' + os.path.realpath('tests/test%20data/image.jpg'),
             'file://' + os.path.realpath('tests/test%20data/a.iso'),
             'file://' + os.path.realpath('tests/test%20data/no%20tags/no-tags.mp3'),
             'file://' + os.path.realpath('tests/test%20data/no%20tags/no-tags.ogg'),
@@ -177,6 +180,7 @@ class BatchUtils(unittest.TestCase):
             'test data/empty/',
             'test data/empty/b/',
             'test data/',
+            'test data/',
             'test data/no tags/',
             'test data/no tags/',
             'test data/no tags/'
@@ -261,6 +265,7 @@ class BatchUtils(unittest.TestCase):
             'main': 'batch', 'output-path': '.',
             'format': 'ogg', 'quality': 20
         }))
+        self.assertFalse(validate_args({'output-resample': 160}))
 
     def test_use_memory_gsettings_cbr(self):
         use_memory_gsettings({
@@ -332,6 +337,36 @@ class BatchUtils(unittest.TestCase):
         gio_settings = get_gio_settings()
         self.assertFalse(gio_settings.get_boolean('delete-original'))
 
+    def test_set_delete_original_true(self):
+        gio_settings = get_gio_settings()
+        gio_settings.set_boolean('delete-original', False)
+        use_memory_gsettings({
+            'output-path': '.',
+            'main': 'batch',
+            'format': 'ogg',
+            'quality': '0.5',
+            'delete-original': True
+        })
+        gio_settings = get_gio_settings()
+        self.assertTrue(gio_settings.get_boolean('delete-original'))
+
+    def test_set_output_sample(self):
+        gio_settings = get_gio_settings()
+        self.assertFalse(gio_settings.get_boolean('output-resample'))
+        self.assertEqual(48000, gio_settings.get_int('resample-rate'))
+
+        use_memory_gsettings({
+            'output-path': '.',
+            'main': 'batch',
+            'format': 'ogg',
+            'quality': '0.5',
+            'output-resample': 44100
+        })
+
+        gio_settings = get_gio_settings()
+        self.assertTrue(gio_settings.get_boolean('output-resample'))
+        self.assertEqual(44100, gio_settings.get_int('resample-rate'))
+
 
 if __name__ == "__main__":
     unittest.main()
