@@ -38,16 +38,27 @@ class DiscovererQueueTest(unittest.TestCase):
     def setUp(self):
         self.gio_settings = get_gio_settings()
         queue = TaskQueue()
-        parent = 'file://' + os.getcwd()
-        sound_files = [
-            SoundFile(parent + '/tests/test%20data/audio/b/c.mp3'),
-            SoundFile(parent + '/tests/test%20data/audio/a.wav'),
-            SoundFile(parent + '/tests/test%20data/audio/strângë chàrs фズ.wav'),
-            SoundFile(parent + '/tests/test%20data/empty/a'),
-            SoundFile(parent + '/tests/test%20data/empty/b/c')
+        parent_dir = 'file://' + os.getcwd()
+        self.sound_files = [
+            SoundFile(parent_dir + '/tests/test%20data/audio/b/c.mp3'),
+            SoundFile(parent_dir + '/tests/test%20data/audio/a.wav'),
+            SoundFile(parent_dir + '/tests/test%20data/empty/b/c'),
+            # add_discoverers will split it here into two tasks or something. Make sure
+            # each of them gets at least one valid audio file in order to test that they
+            # are doing their stuff in parallel.
+            SoundFile(parent_dir + '/tests/test%20data/audio/strângë chàrs фズ.wav'),
+            SoundFile(parent_dir + '/tests/test%20data/empty/a'),
         ]
         self.queue = queue
-        self.sound_files = sound_files
+
+    def wait_for_queue(self):
+        while len(self.queue.done) < len(self.queue.all_tasks):
+            # wait for the test to copmlete
+            time.sleep(0.01)
+            gtk_iteration()
+
+    def tearDown(self):
+        self.wait_for_queue()
 
     def test_add_discoverers(self):
         sound_files = self.sound_files
@@ -63,20 +74,21 @@ class DiscovererQueueTest(unittest.TestCase):
             self.assertFalse(sound_file.readable)
 
         queue.run()
+        # two tasks are running at the same time
         self.assertEqual(len(queue.running), 2)
+
         # add_discoverers creates only one task per job, each task handles
         # multiple sound_files, as opposed to the converter, which only
         # works on a single sound_file.
         self.assertEqual(len(queue.all_tasks), 2)
 
-        while len(queue.done) < 2:
-            time.sleep(0.01)
-            gtk_iteration()
+        self.wait_for_queue()
 
+        # correctly figures out which sound_files contain readable information
         self.assertTrue(sound_files[0].readable)
         self.assertTrue(sound_files[1].readable)
-        self.assertTrue(sound_files[2].readable)
-        self.assertFalse(sound_files[3].readable)
+        self.assertFalse(sound_files[2].readable)
+        self.assertTrue(sound_files[3].readable)
         self.assertFalse(sound_files[4].readable)
 
 
@@ -85,11 +97,11 @@ class DiscovererTest(unittest.TestCase):
     def test_read_tags(self):
         c_mp3 = 'file://' + os.path.realpath('tests/test%20data/audio/b/c.mp3')
         discoverer = Discoverer([SoundFile(c_mp3)])
-        discoverer.set_callback(lambda _: None)
+        discoverer.connect('done', lambda _: None)
         discoverer.run()
 
         done = Mock()
-        discoverer.set_callback(done)
+        discoverer.connect('done', done)
         discoverer.run()
 
         # needs to iterate the main loop for messages on the bus
@@ -117,10 +129,10 @@ class DiscovererTest(unittest.TestCase):
         ]
 
         discoverer = Discoverer(sound_files)
-        discoverer.set_callback(lambda _: None)
+        discoverer.connect('done', lambda _: None)
 
         done = Mock()
-        discoverer.set_callback(done)
+        discoverer.connect('done', done)
         discoverer.run()
 
         # needs to iterate the main loop for messages on the bus
@@ -147,14 +159,19 @@ class DiscovererTest(unittest.TestCase):
         self.assertLess(abs(sound_files[2].duration - 1.00), 0.01)
 
     def test_not_audio(self):
-        c_mp3 = 'file://' + os.path.realpath('tests/test%20data/empty/a')
+        empty = 'file://' + os.path.realpath('tests/test%20data/empty/a')
         a_iso = 'file://' + os.path.realpath('tests/test%20data/a.iso')
-        discoverer = Discoverer([SoundFile(c_mp3), SoundFile(a_iso)])
-        discoverer.set_callback(lambda _: None)
+        image_jpg = 'file://' + os.path.realpath('tests/test%20data/image.jpg')
+        discoverer = Discoverer([
+            SoundFile(empty),
+            SoundFile(a_iso),
+            SoundFile(image_jpg)
+        ])
+        discoverer.connect('done', lambda _: None)
         discoverer.run()
 
         done = Mock()
-        discoverer.set_callback(done)
+        discoverer.connect('done', done)
         discoverer.run()
 
         loop = GLib.MainLoop()
@@ -164,16 +181,13 @@ class DiscovererTest(unittest.TestCase):
 
         done.assert_called_with(discoverer)
 
-        sound_file = discoverer.sound_files[0]
-        self.assertIsNone(sound_file.duration)
-        self.assertFalse(sound_file.readable)
-        self.assertEqual(len(sound_file.tags), 0)
+        self.assertEqual(len(discoverer.sound_files), 3)
+        for sound_file in discoverer.sound_files:
+            self.assertFalse(sound_file.readable)
+            self.assertIsNone(sound_file.duration)
+            self.assertEqual(len(sound_file.tags), 0)
 
-        sound_file = discoverer.sound_files[1]
-        self.assertEqual(is_denylisted(sound_file), '*.iso')
-        self.assertIsNone(sound_file.duration)
-        self.assertFalse(sound_file.readable)
-        self.assertEqual(len(sound_file.tags), 0)
+        self.assertEqual(is_denylisted(discoverer.sound_files[1]), '*.iso')
 
 
 if __name__ == "__main__":
